@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -48,9 +48,9 @@ public:
     /*!
      * Destructor.
      */
-    virtual ~AbstractEngine();
+    virtual ~AbstractEngine() = default;
     /*!
-     * Prepares decoder for usage.
+     * Adds \b source to the internal queue.
      * Subclass should reimplement this function.
      */
     virtual bool enqueue(InputSource *source) = 0;
@@ -81,11 +81,11 @@ public:
     /*!
      * Returns a list of engine factories.
      */
-    static QList<EngineFactory*> factories();
+    static QList<EngineFactory *> factories();
     /*!
      * Returns a list of enabled engine factories.
      */
-    static QList<EngineFactory*> enabledFactories();
+    static QList<EngineFactory *> enabledFactories();
     /*!
      * Returns a list of file name filters, i.e. "*.mp3 *.mpg".
      */
