@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -83,7 +83,7 @@ public:
      * @param parent Parent widget.
      * @return Configuration dialog pointer.
      */
-    virtual QDialog *createConfigDialog(QWidget *parent) = 0;
+    virtual QDialog *createSettings(QWidget *parent) = 0;
     /*!
      * Shows about dialog.
      * @param parent Parent widget.
